@@ -776,7 +776,7 @@ class StagingTable(models.Model):
             else:
                 return None
         else:
-            return self.parent._state_abbr()
+            return self.parent.state
     state = property(_state_abbr)
         
     def _year(self):
