@@ -1,11 +1,23 @@
-import os, re
+import os
+import re
+import logging
+
+import pandas as pd
+import pyhcup
+
+from djhcup_staging.models import State, DataSource, ReferenceColumn
+from djhcup_staging.models import DataSource, FileType, ReferenceColumn
+
+# move these into the local namespace
+BUNDLED_SUMMARY_STATS_DIR = os.path.join(os.path.dirname(pyhcup.__file__), 'data', 'summary_stats')
+
+# start a logger
+logger = logging.getLogger('default')
+
 
 def DataSource_select_or_add(source_dict):
     result = False
-    
-    from djhcup_staging.models import DataSource
     qs = DataSource.objects.filter(**source_dict)
-    
     if qs.count() == 1:
         result = qs[0]
     elif qs.count() == 0:
@@ -17,8 +29,6 @@ def DataSource_select_or_add(source_dict):
 
 def FileType_select_or_add(ft_dict):
     result = False
-    
-    from djhcup_staging.models import FileType
     qs = FileType.objects.filter(**ft_dict)
     if qs.count() == 1:
         result = qs[0]
@@ -29,8 +39,9 @@ def FileType_select_or_add(ft_dict):
     return result
 
 
-def populate_hcup():
-    #these are up top for config/maintenance
+def populate_hcup_ds():
+    """Populates DataSource table with HCUP entries
+    """
     template_pattern = '(?P<state_abbr>[A-Z]{2})_<<file>>_(?P<year>[0-9]{4})_<<category>>\.(?P<file_extension><<file_extension>>)'
     hcup_master = {'name': 'Healthcare Cost and Utilization Project', 'abbreviation': 'HCUP'}
     hcup_files = [{'name': 'State Inpatient Database', 'abbreviation': 'SID', 'patterns': ['SID', 'SIDC']},
@@ -106,7 +117,9 @@ def populate_hcup():
                     ft = FileType_select_or_add(ft_dict)
 
 
-def populate_pudf():
+def populate_pudf_ds():
+    """Populates DataSource table with PUDF entries
+    """
     #these are up top for config/maintenance
     pudf_master = {'name': 'Texas Inpatient Public Use Data File', 'abbreviation': 'PUDF'}
     pudf_categories = [{'name': 'Core discharge data', 'abbreviation': 'base'},
@@ -175,3 +188,59 @@ def populate_pudf():
                                 'compression': 'NONE'
                                 }
                     lft = FileType_select_or_add(lft_dict)
+
+
+def populate_hcup_rc():
+    """Populates ReferenceColumn table using files bundled with PyHCUP
+    """
+    filename_pattern = {
+        'name': 'HCUP CORE Reference Summ Stats',
+        'patterns': [
+            '(?P<repository>SID)_(?P<data_source>CORE)_(?P<state_abbr>[A-Z]{2})_(?P<year>[0-9]{4})_summstatsref\.(?P<file_extension>csv)',
+            ]
+        }
+    
+    populated = 0
+
+    lst_files = pyhcup.hachoir.discover(root_path=BUNDLED_SUMMARY_STATS_DIR, sources=[filename_pattern])
+
+    for x in lst_files:
+        full_path = x['full_path']
+        state_abbr = x['state_abbr']
+        year = x['year']
+        data_source = x['data_source']
+        parent = x['repository']
+        
+        try:
+            ds = DataSource.objects.get(
+                abbreviation__iexact=data_source,
+                parent__abbreviation__iexact=parent
+                )
+            
+            try:
+                st = State.objects.get(
+                    abbreviation__iexact=state_abbr
+                    )
+                df = pd.read_csv(full_path)
+                df.rename(columns={'field': 'name', 'count': 'count_notnull'}, inplace=True)
+                
+                for i, row in df.iterrows():
+                    d = row.to_dict()
+                    d['source'] = ds
+                    d['state'] = st
+                    qs = ReferenceColumn.objects.filter(**d)
+                    if len(qs) > 0:
+                        logger.info("One or more ReferenceColumn objects already recorded for %s %s %s %s: %s" % (ds, state_abbr, year, d['name'], qs))
+                    elif len(qs) == 0:
+                        rc = ReferenceColumn(**d)
+                        rc.save()
+                        logger.info("Added ReferenceColumn object for %s %s %s %s with pk %s" % (ds, rc.state.abbreviation, rc.year, rc.name, rc.pk))
+                        populated += 1
+                    
+            except:
+                logger.error("Unable to add reference column data; no State found matching %s" % (state_abbr))
+
+        except:
+            logger.error("Unable to add reference column data; no DataSource found matching %s %s" % (parent, data_source))
+    
+    return populated
