@@ -332,15 +332,12 @@ def create_batch_from_unimported(request):
 
 
 def batch_from_unprocessed(request):
-    batches = staging.unprocessed_batches()
+    b = staging.unprocessed_batches()
     
-    messages = [
-        "[StagingBatch {pk} ({s})]: {n} ({l} items)" \
+    message = "[StagingBatch {pk} ({s})]: {n} ({l} items)" \
         .format(pk=b.pk, s=b.status, n=b.name, l=b.stagingqueue_set.all())
-        for b in batches
-    ]
     
-    return obj_detail(request, obj_id=b.pk, obj_type="StagingBatch", msg_pt=messages)
+    return obj_detail(request, obj_id=b.pk, obj_type="StagingBatch", msg_pt=[message])
     #return importbatch_inventory(request, msg_pass_through=messages)
 
 
